@@ -22,7 +22,8 @@ module XMonad.Config.Desktop (
     -- the DE via a subset of the Extended Window Manager Hints (EWMH)
     -- specification. Extra xmonad settings unique to specific DE's are
     -- added by overriding or modifying @desktopConfig@ fields in the
-    -- same way that @defaultConfig@ is customized in @~\/.xmonad/xmonad.hs@.
+    -- same way that the default configuration is customized in
+    -- @~\/.xmonad/xmonad.hs@.
     --
     -- For more information about EWMH see:
     --
@@ -69,7 +70,7 @@ import qualified Data.Map as M
 -- <http://haskell.org/haskellwiki/Xmonad>
 --
 -- To configure xmonad for use with a DE or with DE tools like panels
--- and pagers, in place of @defaultConfig@ in your @~\/.xmonad/xmonad.hs@,
+-- and pagers, in place of @def@ in your @~\/.xmonad/xmonad.hs@,
 -- use @desktopConfig@ or one of the other desktop configs from the
 -- @XMonad.Config@ namespace. The following setup and customization examples
 -- work the same way for the other desktop configs as for @desktopConfig@.
@@ -88,7 +89,7 @@ import qualified Data.Map as M
 
 -- $customizing
 -- To customize a desktop config, modify its fields as is illustrated with
--- @defaultConfig@ in "XMonad.Doc.Extending#Extending xmonad".
+-- the default configuration @def@ in "XMonad.Doc.Extending#Extending xmonad".
 
 -- $layouts
 -- See also "XMonad.Util.EZConfig" for more options for modifying key bindings.
@@ -163,11 +164,11 @@ import qualified Data.Map as M
 -- >        adjustEventInput
 --
 
-desktopConfig = ewmh defaultConfig
+desktopConfig = ewmh def
     { startupHook     = setDefaultCursor xC_left_ptr
-    , layoutHook      = desktopLayoutModifiers $ layoutHook defaultConfig
-    , manageHook      = manageHook defaultConfig <+> manageDocks
-    , keys            = desktopKeys <+> keys defaultConfig }
+    , layoutHook      = desktopLayoutModifiers $ layoutHook def
+    , manageHook      = manageHook def <+> manageDocks
+    , keys            = desktopKeys <+> keys def }
 
 desktopKeys (XConfig {modMask = modm}) = M.fromList $
     [ ((modm, xK_b), sendMessage ToggleStruts) ]
