@@ -35,7 +35,7 @@ module XMonad.Hooks.DynamicLog (
     -- * Build your own formatter
     dynamicLogWithPP,
     dynamicLogString,
-    PP(..), defaultPP,
+    PP(..), defaultPP, def,
 
     -- * Example formatters
     dzenPP, xmobarPP, sjanssenPP, byorgeyPP,
@@ -43,6 +43,7 @@ module XMonad.Hooks.DynamicLog (
     -- * Formatting utilities
     wrap, pad, trim, shorten,
     xmobarColor, xmobarStrip,
+    xmobarStripTags,
     dzenColor, dzenEscape, dzenStrip,
 
     -- * Internal formatting functions
@@ -88,7 +89,7 @@ import XMonad.Hooks.ManageDocks
 --
 -- > main = xmonad =<< xmobar myConfig
 -- >
--- > myConfig = defaultConfig { ... }
+-- > myConfig = def { ... }
 --
 -- There is also 'statusBar' if you'd like to use another status bar, or would
 -- like to use different formatting options.  The 'xmobar', 'dzen', and
@@ -99,7 +100,7 @@ import XMonad.Hooks.ManageDocks
 -- ('dynamicLog' or 'dynamicLogXinerama') by simply setting your logHook to the
 -- appropriate function, for instance:
 --
--- > main = xmonad $ defaultConfig {
+-- > main = xmonad $ def {
 -- >    ...
 -- >    logHook = dynamicLog
 -- >    ...
@@ -124,9 +125,9 @@ import XMonad.Hooks.ManageDocks
 -- >
 -- > main = do
 -- >     h <- spawnPipe "xmobar -options -foo -bar"
--- >     xmonad $ defaultConfig {
+-- >     xmonad $ def {
 -- >       ...
--- >       logHook = dynamicLogWithPP $ defaultPP { ppOutput = hPutStrLn h }
+-- >       logHook = dynamicLogWithPP $ def { ppOutput = hPutStrLn h }
 --
 -- If you use @spawnPipe@, be sure to redefine the 'ppOutput' field of
 -- your pretty-printer as in the example above; by default the status
@@ -153,7 +154,7 @@ import XMonad.Hooks.ManageDocks
 --
 -- > main = xmonad =<< dzen myConfig
 -- >
--- > myConfig = defaultConfig { ... }
+-- > myConfig = def { ... }
 --
 -- The intent is that the above config file should provide a nice
 -- status bar with minimal effort.
@@ -178,7 +179,7 @@ dzen conf = statusBar ("dzen2 " ++ flags) dzenPP toggleStrutsKey conf
 --
 -- > main = xmonad =<< xmobar myConfig
 -- >
--- > myConfig = defaultConfig { ... }
+-- > myConfig = def { ... }
 --
 -- This works pretty much the same as 'dzen' function above.
 --
@@ -246,7 +247,7 @@ toggleStrutsKey XConfig{modMask = modm} = (modm, xK_b )
 -- To customize the output format, see 'dynamicLogWithPP'.
 --
 dynamicLog :: X ()
-dynamicLog = dynamicLogWithPP defaultPP
+dynamicLog = dynamicLogWithPP def
 
 -- | Format the current status using the supplied pretty-printing format,
 --   and write it to stdout.
@@ -312,10 +313,10 @@ pprWindowSet sort' urgents pp s = sepBy (ppWsSep pp) . map fmt . sort' $
 -- using 'dynamicLogWithPP' by setting 'ppSort' to /getSortByXineramaRule/ from
 -- "XMonad.Util.WorkspaceCompare".  For example,
 --
--- > defaultPP { ppCurrent = dzenColor "red" "#efebe7"
--- >           , ppVisible = wrap "[" "]"
--- >           , ppSort    = getSortByXineramaRule
--- >           }
+-- > def { ppCurrent = dzenColor "red" "#efebe7"
+-- >     , ppVisible = wrap "[" "]"
+-- >     , ppSort    = getSortByXineramaRule
+-- >     }
 dynamicLogXinerama :: X ()
 dynamicLogXinerama = withWindowSet $ io . putStrLn . pprWindowSetXinerama
 
@@ -394,9 +395,14 @@ xmobarColor fg bg = wrap t "</fc>"
 
 -- ??? add an xmobarEscape function?
 
--- | Strip xmobar markup.
+-- | Strip xmobar markup, specifically the <fc>, <icon> and <action> tags and
+-- the matching tags like </fc>.
 xmobarStrip :: String -> String
-xmobarStrip = xmobarStripTags ["fc","icon","action"] where
+xmobarStrip = converge (xmobarStripTags ["fc","icon","action"]) where
+
+converge :: (Eq a) => (a -> a) -> a -> a
+converge f a = let xs = iterate f a
+    in fst $ head $ dropWhile (uncurry (/=)) $ zip xs $ tail xs
 
 xmobarStripTags :: [String] -- ^ tags
         -> String -> String -- ^ with all <tag>...</tag> removed
@@ -473,8 +479,12 @@ data PP = PP { ppCurrent :: WorkspaceId -> String
              }
 
 -- | The default pretty printing options, as seen in 'dynamicLog'.
+{-# DEPRECATED defaultPP "Use def (from Data.Default, and re-exported by XMonad.Hooks.DynamicLog) instead." #-}
 defaultPP :: PP
-defaultPP = PP { ppCurrent         = wrap "[" "]"
+defaultPP = def
+
+instance Default PP where
+    def   = PP { ppCurrent         = wrap "[" "]"
                , ppVisible         = wrap "<" ">"
                , ppHidden          = id
                , ppHiddenNoWindows = const ""
@@ -492,7 +502,7 @@ defaultPP = PP { ppCurrent         = wrap "[" "]"
 
 -- | Settings to emulate dwm's statusbar, dzen only.
 dzenPP :: PP
-dzenPP = defaultPP { ppCurrent  = dzenColor "white" "#2b4f98" . pad
+dzenPP = def { ppCurrent  = dzenColor "white" "#2b4f98" . pad
                    , ppVisible  = dzenColor "black" "#999999" . pad
                    , ppHidden   = dzenColor "black" "#cccccc" . pad
                    , ppHiddenNoWindows = const ""
@@ -511,7 +521,7 @@ dzenPP = defaultPP { ppCurrent  = dzenColor "white" "#2b4f98" . pad
 
 -- | Some nice xmobar defaults.
 xmobarPP :: PP
-xmobarPP = defaultPP { ppCurrent = xmobarColor "yellow" "" . wrap "[" "]"
+xmobarPP = def { ppCurrent = xmobarColor "yellow" "" . wrap "[" "]"
                      , ppTitle   = xmobarColor "green"  "" . shorten 40
                      , ppVisible = wrap "(" ")"
                      , ppUrgent  = xmobarColor "red" "yellow"
@@ -519,23 +529,23 @@ xmobarPP = defaultPP { ppCurrent = xmobarColor "yellow" "" . wrap "[" "]"
 
 -- | The options that sjanssen likes to use with xmobar, as an
 -- example.  Note the use of 'xmobarColor' and the record update on
--- 'defaultPP'.
+-- 'def'.
 sjanssenPP :: PP
-sjanssenPP = defaultPP { ppCurrent = xmobarColor "white" "black"
-                       , ppTitle = xmobarColor "#00ee00" "" . shorten 120
-                       }
+sjanssenPP = def { ppCurrent = xmobarColor "white" "black"
+                 , ppTitle = xmobarColor "#00ee00" "" . shorten 120
+                 }
 
 -- | The options that byorgey likes to use with dzen, as another example.
 byorgeyPP :: PP
-byorgeyPP = defaultPP { ppHiddenNoWindows = showNamedWorkspaces
-                      , ppHidden  = dzenColor "black"  "#a8a3f7" . pad
-                      , ppCurrent = dzenColor "yellow" "#a8a3f7" . pad
-                      , ppUrgent  = dzenColor "red"    "yellow"  . pad
-                      , ppSep     = " | "
-                      , ppWsSep   = ""
-                      , ppTitle   = shorten 70
-                      , ppOrder   = reverse
-                      }
+byorgeyPP = def { ppHiddenNoWindows = showNamedWorkspaces
+                , ppHidden  = dzenColor "black"  "#a8a3f7" . pad
+                , ppCurrent = dzenColor "yellow" "#a8a3f7" . pad
+                , ppUrgent  = dzenColor "red"    "yellow"  . pad
+                , ppSep     = " | "
+                , ppWsSep   = ""
+                , ppTitle   = shorten 70
+                , ppOrder   = reverse
+                }
   where showNamedWorkspaces wsId = if any (`elem` wsId) ['a'..'z']
                                        then pad wsId
                                        else ""
