@@ -44,8 +44,8 @@ import XMonad.Util.WindowProperties (getProp32)
 -- > import XMonad
 -- > import XMonad.Hooks.EwmhDesktops
 -- >
--- > main = xmonad $ ewmh defaultConfig{ handleEventHook =
--- >            handleEventHook defaultConfig <+> fullscreenEventHook }
+-- > main = xmonad $ ewmh def{ handleEventHook =
+-- >            handleEventHook def <+> fullscreenEventHook }
 --
 -- You may also be interested in 'avoidStruts' from "XMonad.Hooks.ManageDocks".
 
@@ -55,7 +55,8 @@ ewmh :: XConfig a -> XConfig a
 ewmh c = c { startupHook     = startupHook c +++ ewmhDesktopsStartup
            , handleEventHook = handleEventHook c +++ ewmhDesktopsEventHook
            , logHook         = logHook c +++ ewmhDesktopsLogHook }
- where x +++ y = mappend x y
+ -- @@@ will fix this correctly later with the rewrite
+ where x +++ y = mappend y x
 
 -- |
 -- Initializes EwmhDesktops and advertises EWMH support to the X
