@@ -1,7 +1,7 @@
-{-# LANGUAGE DeriveDataTypeable, MultiParamTypeClasses, FlexibleInstances, TypeSynonymInstances #-}
+{-# LANGUAGE DeriveDataTypeable, FlexibleContexts, MultiParamTypeClasses, FlexibleInstances, TypeSynonymInstances #-}
 -----------------------------------------------------------------------------
 -- |
--- Module      :  XMonad.Layout.Decoration
+-- Module      :  XMonad.Layout.Fullscreen
 -- Copyright   :  (c) 2010 Audun Skaugen
 -- License     :  BSD-style (see xmonad/LICENSE)
 --
@@ -15,7 +15,8 @@
 module XMonad.Layout.Fullscreen
     ( -- * Usage:
       -- $usage
-     fullscreenFull
+     fullscreenSupport
+    ,fullscreenFull
     ,fullscreenFocus
     ,fullscreenFullRect
     ,fullscreenFocusRect
@@ -53,9 +54,9 @@ import Control.Arrow (second)
 -- To use this module, add 'fullscreenEventHook' and 'fullscreenManageHook'
 -- to your config, i.e.
 --
--- > xmonad defaultconfig { handleEventHook = fullscreenEventHook,
--- >                        manageHook = fullscreenManageHook,
--- >                        layoutHook = myLayouts }
+-- > xmonad def { handleEventHook = fullscreenEventHook,
+-- >              manageHook = fullscreenManageHook,
+-- >              layoutHook = myLayouts }
 --
 -- Now you can use layouts that respect fullscreen, for example the
 -- provided 'fullscreenFull':
@@ -63,6 +64,20 @@ import Control.Arrow (second)
 -- > myLayouts = fullscreenFull someLayout
 --
 
+-- | Modifies your config to apply basic fullscreen support -- fullscreen
+-- windows when they request it. Example usage:
+--
+-- > main = xmonad
+-- >      $ fullscreenSupport
+-- >      $ defaultConfig { ... }
+fullscreenSupport :: LayoutClass l Window =>
+  XConfig l -> XConfig (ModifiedLayout FullscreenFull l)
+fullscreenSupport c = c {
+    layoutHook = fullscreenFull $ layoutHook c,
+    handleEventHook = handleEventHook c <+> fullscreenEventHook,
+    manageHook = manageHook c <+> fullscreenManageHook
+  }
+
 -- | Messages that control the fullscreen state of the window.
 -- AddFullscreen and RemoveFullscreen are sent to all layouts
 -- when a window wants or no longer wants to be fullscreen.
