@@ -17,6 +17,7 @@ module XMonad.Layout.ShowWName
       -- $usage
       showWName
     , showWName'
+    , def
     , defaultSWNConfig
     , SWNConfig(..)
     , ShowWName
@@ -34,8 +35,8 @@ import XMonad.Util.XUtils
 -- @~\/.xmonad\/xmonad.hs@:
 --
 -- > import XMonad.Layout.ShowWName
--- > myLayout = layoutHook defaultConfig
--- > main = xmonad defaultConfig { layoutHook = showWName myLayout }
+-- > myLayout = layoutHook def
+-- > main = xmonad def { layoutHook = showWName myLayout }
 --
 -- For more detailed instructions on editing the layoutHook see:
 --
@@ -43,7 +44,7 @@ import XMonad.Util.XUtils
 
 -- | A layout modifier to show the workspace name when switching
 showWName :: l a -> ModifiedLayout ShowWName l a
-showWName = ModifiedLayout (SWN True defaultSWNConfig Nothing)
+showWName = ModifiedLayout (SWN True def Nothing)
 
 -- | A layout modifier to show the workspace name when switching. It
 -- is possible to provide a custom configuration.
@@ -60,14 +61,18 @@ data SWNConfig =
          , swn_fade    :: Rational -- ^ Time in seconds of the name visibility
     } deriving (Read, Show)
 
-defaultSWNConfig :: SWNConfig
-defaultSWNConfig =
+instance Default SWNConfig where
+  def =
     SWNC { swn_font    = "-misc-fixed-*-*-*-*-20-*-*-*-*-*-*-*"
          , swn_bgcolor = "black"
          , swn_color   = "white"
          , swn_fade    = 1
          }
 
+{-# DEPRECATED defaultSWNConfig "Use def (from Data.Default, and re-exported from XMonad.Layout.ShowWName) instead." #-}
+defaultSWNConfig :: SWNConfig
+defaultSWNConfig = def
+
 instance LayoutModifier ShowWName a where
     redoLayout      sn r _ wrs = doShow sn r wrs
 
@@ -99,6 +104,5 @@ flashName c (Rectangle sx sy wh ht) wrs = do
   showWindow w
   paintAndWrite w f (fi width) (fi hight) 0 (swn_bgcolor c) "" (swn_color c) (swn_bgcolor c) [AlignCenter] [n]
   releaseXMF f
-  io $ sync d False
   i <- startTimer (swn_fade c)
   return (wrs, Just $ SWN False c $ Just (i,w))
