@@ -21,7 +21,7 @@ module XMonad.Layout.WindowNavigation (
                                    Navigate(..), Direction2D(..),
                                    MoveWindowToWindow(..),
                                    navigateColor, navigateBrightness,
-                                   noNavigateBorders, defaultWNConfig,
+                                   noNavigateBorders, defaultWNConfig, def,
                                    WNConfig, WindowNavigation,
                                   ) where
 
@@ -42,7 +42,7 @@ import XMonad.Util.XUtils
 -- to some layout:
 --
 -- > myLayout = windowNavigation (Tall 1 (3/100) (1/2))  ||| Full ||| etc..
--- > main = xmonad defaultConfig { layoutHook = myLayout }
+-- > main = xmonad def { layoutHook = myLayout }
 --
 -- For more detailed instructions on editing the layoutHook see:
 --
@@ -82,24 +82,27 @@ data WNConfig =
 
 noNavigateBorders :: WNConfig
 noNavigateBorders =
-    defaultWNConfig {brightness = Just 0}
+    def {brightness = Just 0}
 
 navigateColor :: String -> WNConfig
 navigateColor c =
     WNC Nothing c c c c
 
 navigateBrightness :: Double -> WNConfig
-navigateBrightness f = defaultWNConfig { brightness = Just $ max 0 $ min 1 f }
+navigateBrightness f = def { brightness = Just $ max 0 $ min 1 f }
 
+instance Default WNConfig where def = WNC (Just 0.4) "#0000FF" "#00FFFF" "#FF0000" "#FF00FF"
+
+{-# DEPRECATED defaultWNConfig "Use def (from Data.Default, and re-exported by XMonad.Layout.WindowNavigation) instead." #-}
 defaultWNConfig :: WNConfig
-defaultWNConfig = WNC (Just 0.4) "#0000FF" "#00FFFF" "#FF0000" "#FF00FF"
+defaultWNConfig = def
 
 data NavigationState a = NS Point [(a,Rectangle)]
 
 data WindowNavigation a = WindowNavigation WNConfig (Invisible Maybe (NavigationState a)) deriving ( Read, Show )
 
 windowNavigation :: LayoutClass l a => l a -> ModifiedLayout WindowNavigation l a
-windowNavigation = ModifiedLayout (WindowNavigation defaultWNConfig (I Nothing))
+windowNavigation = ModifiedLayout (WindowNavigation def (I Nothing))
 
 configurableNavigation :: LayoutClass l a => WNConfig -> l a -> ModifiedLayout WindowNavigation l a
 configurableNavigation conf = ModifiedLayout (WindowNavigation conf (I Nothing))
