@@ -1,8 +1,9 @@
+{-# LANGUAGE FlexibleContexts #-}
 {-# LANGUAGE ExistentialQuantification #-}
 -----------------------------------------------------------------------------
 -- |
 -- Module      :  XMonad.Prompt
--- Copyright   :  (C) 2007 Andrea Rossato
+-- Copyright   :  (C) 2007 Andrea Rossato, 2015 Evgeny Kurnevsky
 -- License     :  BSD3
 --
 -- Maintainer  :  Spencer Janssen <spencerjanssen@gmail.com>
@@ -19,6 +20,7 @@ module XMonad.Prompt
       mkXPrompt
     , mkXPromptWithReturn
     , mkXPromptWithModes
+    , def
     , amberXPConfig
     , defaultXPConfig
     , greenXPConfig
@@ -134,6 +136,8 @@ data XPConfig =
         , position          :: XPPosition -- ^ Position: 'Top' or 'Bottom'
         , alwaysHighlight   :: !Bool      -- ^ Always highlight an item, overriden to True with multiple modes. This implies having *one* column of autocompletions only.
         , height            :: !Dimension -- ^ Window height
+        , maxComplRows      :: Maybe Dimension
+                                          -- ^ Just x: maximum number of rows to show in completion window
         , historySize       :: !Int       -- ^ The number of history entries to be saved
         , historyFilter     :: [String] -> [String]
                                          -- ^ a filter to determine which
@@ -193,7 +197,6 @@ class XPrompt t where
 
     -- | This method is used to generate the string to be passed to
     -- the completion function.
-    -- This function is not used when in multiple modes (because alwaysHighlight in XPConfig is True)
     commandToComplete :: t -> String -> String
     commandToComplete _ = getLastWord
 
@@ -229,7 +232,8 @@ data XPPosition = Top
 
 amberXPConfig, defaultXPConfig, greenXPConfig :: XPConfig
 
-defaultXPConfig =
+instance Default XPConfig where
+  def =
     XPC { font              = "-misc-fixed-*-*-*-*-12-*-*-*-*-*-*-*"
         , bgColor           = "grey22"
         , fgColor           = "grey80"
@@ -242,6 +246,7 @@ defaultXPConfig =
         , changeModeKey     = xK_grave
         , position          = Bottom
         , height            = 18
+        , maxComplRows      = Nothing
         , historySize       = 256
         , historyFilter     = id
         , defaultText       = []
@@ -250,8 +255,10 @@ defaultXPConfig =
         , searchPredicate   = isPrefixOf
         , alwaysHighlight   = False
         }
-greenXPConfig = defaultXPConfig { fgColor = "green", bgColor = "black", promptBorderWidth = 0 }
-amberXPConfig = defaultXPConfig { fgColor = "#ca8f2d", bgColor = "black", fgHLight = "#eaaf4c" }
+{-# DEPRECATED defaultXPConfig "Use def (from Data.Default, and re-exported from XMonad.Prompt) instead." #-}
+defaultXPConfig = def
+greenXPConfig = def { fgColor = "green", bgColor = "black", promptBorderWidth = 0 }
+amberXPConfig = def { fgColor = "#ca8f2d", bgColor = "black", fgHLight = "#eaaf4c" }
 
 initState :: Display -> Window -> Window -> Rectangle -> XPOperationMode
           -> GC -> XMonadFont -> [String] -> XPConfig -> KeyMask -> XPState
@@ -367,7 +374,7 @@ mkXPromptWithReturn t conf compl action = do
       --When it is false, it is handled depending on the prompt buffer's value
     let selectedCompletion = case alwaysHighlight (config st') of
           False -> command st'
-          True -> fromMaybe "" $ highlightedCompl st'
+          True -> fromMaybe (command st') $ highlightedCompl st'
     Just <$> action selectedCompletion
     else return Nothing
 
@@ -375,8 +382,7 @@ mkXPromptWithReturn t conf compl action = do
 --
 -- * a prompt type, instance of the 'XPrompt' class.
 --
--- * a prompt configuration ('defaultXPConfig' can be used as a
--- starting point)
+-- * a prompt configuration ('def' can be used as a starting point)
 --
 -- * a completion function ('mkComplFunFromList' can be used to
 -- create a completions function given a list of possible completions)
@@ -795,9 +801,13 @@ moveWord' p d = do
   modify $ \s -> s { offset = newoff }
 
 moveHistory :: (W.Stack String -> W.Stack String) -> XP ()
-moveHistory f = modify $ \s -> let ch = f $ commandHistory s
-                               in s { commandHistory = ch
-                                    , offset         = length $ W.focus ch }
+moveHistory f = do
+  modify $ \s -> let ch = f $ commandHistory s
+                 in s { commandHistory = ch
+                      , offset         = length $ W.focus ch
+                      , complIndex     = (0,0) }
+  updateWindows
+  updateHighlightedCompl
 
 updateHighlightedCompl :: XP ()
 updateHighlightedCompl = do
@@ -934,7 +944,10 @@ getComplWinDim compl = do
       rem_height =  rect_height scr - ht
       (rows,r) = length compl `divMod` fi columns
       needed_rows = max 1 (rows + if r == 0 then 0 else 1)
-      actual_max_number_of_rows = rem_height `div` ht
+      limit_max_number = case maxComplRows c of
+                           Nothing -> id
+                           Just m -> min m
+      actual_max_number_of_rows = limit_max_number $ rem_height `div` ht
       actual_rows = min actual_max_number_of_rows (fi needed_rows)
       actual_height = actual_rows * ht
       (x,y) = case position c of
@@ -1187,10 +1200,10 @@ historyNextMatching hm@(HistoryMatches ref) next = do
 -- > ..
 -- > ((modMask,xK_p), shellPrompt . myPrompt =<< initMatches)
 -- > ..
--- > myPrompt ref = defaultPrompt
+-- > myPrompt ref = def
 -- >   { promptKeymap = M.union [((0,xK_Up), historyUpMatching ref)
 -- >                            ,((0,xK_Down), historyDownMatching ref)]
--- >                            (promptKeymap defaultPrompt)
+-- >                            (promptKeymap def)
 -- >   , .. }
 --
 historyUpMatching, historyDownMatching :: HistoryMatches -> XP ()
