@@ -41,7 +41,7 @@ econst = const . return
 
 2. In your keybindings add something like:
 
->   , ((modm .|. controlMask, xK_x), runOrRaisePrompt defaultXPConfig)
+>   , ((modm .|. controlMask, xK_x), runOrRaisePrompt def)
 
 For detailed instruction on editing the key binding see
 "XMonad.Doc.Extending#Editing_key_bindings". -}
@@ -52,7 +52,7 @@ instance XPrompt RunOrRaisePrompt where
 
 runOrRaisePrompt :: XPConfig -> X ()
 runOrRaisePrompt c = do cmds <- io getCommands
-                        mkXPrompt RRP c (getShellCompl cmds) open
+                        mkXPrompt RRP c (getShellCompl cmds $ searchPredicate c) open
 open :: String -> X ()
 open path = io (isNormalFile path) >>= \b ->
             if b
